// -*-Mode: C++;-*-
/*
 * $Id: MainApp.h,v 2.12 2003/02/04 00:08:53 ral Exp $
 */

#ifndef CMainApp_included
#define CMainApp_included

#include "kmainwindow.h"
#include <qfile.h>
#include <kmenubar.h>
#include "sendmessage.h"

class CMainWindow;

class CMainApp : public KMainWindow,virtual public CSendMessage
{
    Q_OBJECT

public:
    CMainApp ( const char* name = NULL,bool _first = false );
    
    virtual ~CMainApp();
    virtual void append_message(const char*text);
    virtual void append_message(const std::string&message);
    
protected:
    QPopupMenu*file;
    QPopupMenu*db_menu;
    QPopupMenu*setup_menu;
    int logf;
    QString logfile;
    QFile filepointer;
    KMenuBar*MenuBar;
    CMainWindow* MainWidget;

    void initToolbar();

protected slots:
    void new_window();
    void raus_hier();
    void set_LogFileName();
    void connected_to_server(const char*);
    void disconnected_from_server();
    bool queryExit();
    bool queryClose();
    void layout_setup();

public slots:
    void windowClose();
signals:
};
#endif // CMainApp_included
